#-----------------------------
# -- fundb --
#-----------------------------

from . import adapters, jsonquery, lib, database, cursor

# alias to Database
fundb = database.Database
